Stan Math Library: stan/math/rev/scal/fun/tgamma.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

tgamma.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_TGAMMA_HPP
2 #define STAN_MATH_REV_SCAL_FUN_TGAMMA_HPP
3
4 #include <boost/math/special_functions/digamma.hpp>
5 #include <stan/math/rev/core.hpp>
6
7 namespace stan {
8 namespace math {
9
10 namespace {
11 class tgamma_vari : public op_v_vari {
12 public:
13 explicit tgamma_vari(vari* avi) :
14 op_v_vari(boost::math::tgamma(avi->val_), avi) {
15 }
16 void chain() {
17 avi_->adj_ += adj_ * val_ * boost::math::digamma(avi_->val_);
18 }
19 };
20 }
21
65 inline var tgamma(const stan::math::var& a) {
66 return var(new tgamma_vari(a.vi_));
67 }
68
69 }
70 }
71 #endif
core.hpp
boost
Reimplementing boost functionality.
Definition: boost_fpclassify.hpp:7
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
stan::math::tgamma
fvar< T > tgamma(const fvar< T > &x)
Definition: tgamma.hpp:15
stan::math::digamma
fvar< T > digamma(const fvar< T > &x)
Definition: digamma.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.